@@ -33,6 +33,10 @@ def calculate_real_time_k_line_param(real_time_quotes_now):
     real_time_quotes_now['chg_from_open'] = round(
         (((real_time_quotes_now['now_price'] - real_time_quotes_now['open']) / real_time_quotes_now[
             'open']) * 100), 2)
+    # 最低和最高之间的差值
+    real_time_quotes_now['high_from_low_chg'] = round(
+        (((real_time_quotes_now['high'] - real_time_quotes_now['low']) / real_time_quotes_now[
+            'low']) * 100), 2)
 
     if 'average_price' in real_time_quotes_now.columns:
         # 高于平均线的差值 越大表明极速拉伸
